pub struct DeepstoreClient { /* private fields */ }Expand description
High-level DeepStore client that coordinates control plane and data plane calls
Implementations
Sourceimpl DeepstoreClient
impl DeepstoreClient
Sourcepub fn builder() -> DeepstoreClientBuilder
pub fn builder() -> DeepstoreClientBuilder
Create a new client builder
Sourcepub async fn search(&self, params: SearchParams) -> Result<SearchResult>
pub async fn search(&self, params: SearchParams) -> Result<SearchResult>
Search for documents
Fetches splits from control plane, then searches via auth proxy.
For dev/testing environments where splits aren’t tracked, the data plane can search an in-memory buffer by passing an empty splits array.
Sourcepub async fn get_draft_documents(
&self,
database_id: &str,
draft_ids: Vec<String>,
) -> Result<DraftDocumentBatch>
pub async fn get_draft_documents( &self, database_id: &str, draft_ids: Vec<String>, ) -> Result<DraftDocumentBatch>
Fetch documents from draft files
Used for streaming - fetches raw documents before indexing.
Sourcepub fn build_sse_url(&self, params: &StreamParams, token: &str) -> String
pub fn build_sse_url(&self, params: &StreamParams, token: &str) -> String
Build SSE URL for streaming
Returns the URL with token as query parameter (EventSource can’t send headers).